@@ -264,7 +264,7 @@ RPS <- function(geno,N)
 EMI <- function(geno) 
 {
   #EMI_result= do.call(rrBLUP::A.mat,args=c(X=geno, arg.A.mat))$imputed
-  EMI_result= A.mat(X=geno, impute.method = "EM", tol = 0.02, return.imputed = TRUE)$imputed
+  EMI_result= rrBLUP::A.mat(X=geno, impute.method = "EM", tol = 0.02, return.imputed = TRUE)$imputed
   return(EMI_result)
   
 }
@@ -978,7 +978,7 @@ predict_BA <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   nIter=5000;
   burnIn=1000;
   thin=3;
-  saveAt ='';
+  saveAt = stringi::stri_rand_strings(1, 32, '[a-zA-Z]');
   S0=NULL;
   weights=NULL;
   R2=0.5;
@@ -1004,7 +1004,7 @@ predict_BA <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     #MODEL2=BGLR(y=y,ETA=NULL,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
   
-  
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
@@ -1053,7 +1053,7 @@ predict_BB <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   nIter=5000
   burnIn=1000
   thin=10
-  saveAt=''
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]')
   S0=NULL
   weights=NULL
   R2=0.5
@@ -1074,6 +1074,7 @@ predict_BB <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     MODEL=BGLR(y=yNa,ETA=ETA,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
   
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
@@ -1133,7 +1134,7 @@ predict_BC <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   nIter=5000
   burnIn=1000
   thin=3
-  saveAt=''
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]')
   S0=NULL
   weights=NULL
   R2=0.5
@@ -1153,7 +1154,7 @@ predict_BC <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     #MODEL=do.call(BGLR,args=c(y=yNa,arg.BGLR))
     MODEL=BGLR(y=yNa,ETA=ETA,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
-  
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
@@ -1205,7 +1206,7 @@ predict_BL <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   nIter=5000;
   burnIn=1000;
   thin=3;
-  saveAt='';
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]');
   S0=NULL;
   weights=NULL;
   R2=0.5;
@@ -1224,8 +1225,7 @@ predict_BL <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     #MODEL=do.call(BGLR(y=yNa,arg.BGLR))
     MODEL=BGLR(y=yNa,ETA=ETA,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
-  
-  
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
@@ -1278,7 +1278,7 @@ predict_BRR <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   
   000;
   thin=3;
-  saveAt='';
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]');
   S0=NULL;
   weights=NULL;
   R2=0.5;
@@ -1300,7 +1300,7 @@ predict_BRR <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     MODEL=BGLR(y=yNa,ETA=ETA,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
   
-  
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
@@ -1622,13 +1622,13 @@ predict_RKHS <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
   D <- (as.matrix(dist(X,method='euclidean'))^2)/p
   h <- 0.5
   K=exp(-h*D)
-  
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]');
   if(FixedTrain!="NULL")
   {
     FIX <- rbind(FixedTrain,FixedPred)
     FIX=round(FIX)
     ETA2<-list(list(X=FIX,model="FIXED"),list(K=K, model='RKHS'))
-    MODEL=BGLR(y=yNa,ETA=ETA2,nIter=5000, burnIn=1000)
+    MODEL=BGLR(y=yNa,ETA=ETA2,nIter=5000, burnIn=1000, saveAt = saveAt)
     fm=MODEL
   }
   else
@@ -1636,12 +1636,12 @@ predict_RKHS <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPred)
     
     ETA= list(list(K=K, model='RKHS'))
     # PREDICT <- do.call(BGLR::BGLR,args=c(y=yNa,ETA=ETA,arg.BGLR))
-    MODEL <- BGLR(y=yNa,ETA=ETA,nIter=5000, burnIn=1000)
+    MODEL <- BGLR(y=yNa,ETA=ETA,nIter=5000, burnIn=1000, saveAt = saveAt)
   }
   gpred = MODEL$yHat
   gpredSD=MODEL$SD.yHat
   GPRED=cbind(gpred,gpredSD)
-  
+  removeSaveAt(saveAt)
   
   VARU=var(gpred)   # See: BGLR Genomics.cimmyt.org/BGLR-extdoc.pdf
   SDU=MODEL$SD.yHat
@@ -1711,7 +1711,7 @@ predict_EGBLUP <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPre
   nIter=5000;
   burnIn=1000;
   thin=3;
-  saveAt='';
+  saveAt=stringi::stri_rand_strings(1, 32, '[a-zA-Z]');
   S0=NULL;
   weights=NULL;
   R2=0.5;
@@ -1730,7 +1730,7 @@ predict_EGBLUP <- function(phenoTrain, genoTrain, FixedTrain, genoPred, FixedPre
     ETA<-list(list(X=GENO,model='BRR'),list(K=A_GENO*A_GENO,model='RKHS'))
     MODEL=BGLR(y=yNa,ETA=ETA,nIter=nIter,burnIn=burnIn,thin=thin,saveAt=saveAt,df0=5,S0=S0,weights=weights,R2=R2)
   }
-  
+  removeSaveAt(saveAt)
   gpred = MODEL$yHat
   #gpred=predict(MODEL)
   gpredSD=MODEL$SD.yHat
@@ -2122,3 +2122,16 @@ contrasteNonPheno=function(NotSampled,Nind,NSample)
   return(mat)
 }
 
+
+#' Remove saveAt file generated by BGLR package
+#'
+#' @param saveAt saveAt
+removeSaveAt <- function(saveAt) {
+  Sys.sleep(2)
+  files <- list.files('.', paste0("^", saveAt, '.*(lambda|mu|varE|varB|varU|ScaleBayesA|parBayesB|parBayesC)\\.dat$'))
+  tryCatch({
+    invisible(lapply(files, file.remove))
+  }, error = function(e) {
+    
+  })
+}
